@@ -1,15 +1,18 @@
+from pkgutil import get_data
 from typing import Tuple
-import dash_core_components as dcc
-import dash_html_components as html
+
 import pandas as pd
 import plotly.graph_objs as go
+from dash import dcc, html
 from dash.dependencies import Input, Output
-from plotly.subplots import make_subplots
 from statsmodels.tsa.api import seasonal_decompose
+from ts_app import plotting
 from ts_app.dash_app import app
 from ts_app.ts_functions import create_arma_sample, fit_arima_model
 
-param_input = html.Div(
+summary = get_data("ts_app", "assets/summary.md").decode()
+
+model_param_input = html.Div(
     id="model-params",
     className="param-input",
     children=[
@@ -47,34 +50,52 @@ param_input = html.Div(
     ],
 )
 
-lineplot = html.Div(
-    className="lineplot",
-    children=[
-        dcc.Loading(
-            color="#777",
-            children=[
-                dcc.Graph(id="time-series-graph"),
-            ],
-        )
-    ],
-)
-
-component_plots = html.Div(
-    className="subplots",
+graphs_and_guide = html.Div(
+    className="graphs-and-guide",
     children=[
         dcc.Loading(
             color="#777",
             children=[
                 dcc.Graph(id="component-plots"),
             ],
-        )
+        ),
+        html.Div(
+            className="line-plot-and-summary",
+            children=[
+                dcc.Loading(
+                    color="#777",
+                    children=[
+                        dcc.Graph(
+                            id="line-plot",
+                            config={"toImageButtonOptions": {"format": "svg"}},
+                        ),
+                    ],
+                ),
+                dcc.Markdown(summary),
+                html.Div(
+                    className="footer",
+                    children=[
+                        html.A(
+                            "Back to home",
+                            href="/",
+                            className="hvr-bob button",
+                        ),
+                        html.A(
+                            "Browse glossary",
+                            href="/glossary",
+                            className="hvr-bob button",
+                        ),
+                    ],
+                ),
+            ],
+        ),
     ],
 )
 
 
 @app.callback(
     [
-        Output("time-series-graph", "figure"),
+        Output("line-plot", "figure"),
         Output("component-plots", "figure"),
     ],
     [
@@ -83,7 +104,7 @@ component_plots = html.Div(
         Input("model-ma", "value"),
         Input("url", "pathname"),
         Input("sample-data-store", "data"),
-        Input("upload-data-store", "data"),
+        Input("file-upload-store", "data"),
     ],
 )
 def model_and_predict(
@@ -112,77 +133,34 @@ def model_and_predict(
         A line-plot of the forecast results, and subplots with seasonal
         decomposition estimates.
     """
-    if input_source == "/upload":
-        data_store = upload
-    elif input_source == "/sample":
-        data_store = sample
-
-    if data_store is None:  # Default if there's no data
+    if input_source == "/upload" and upload is not None:
+        filename = upload["filename"]
+        data = pd.read_json(upload["data"], orient="index", typ="series")
+    elif input_source == "/sample" and sample is not None:
+        filename = sample["filename"]
+        data = pd.read_json(sample["data"], orient="index", typ="series")
+    else:
         filename = "a random sample"
         data = create_arma_sample()
-    else:
-        filename = data_store["filename"]
-        json_data = data_store["data"]
-        data = pd.read_json(json_data, orient="index", typ="series")
 
     predictions, forecast = fit_arima_model(
         data, ar_order, diff_order, ma_order
     )
 
-    lineplot = go.Figure()
-    lineplot.add_trace(
-        go.Scatter(y=data, x=data.index, mode="lines", name="actual data")
+    line_plot = plotting.plot_forecast(
+        actual_data=data,
+        predictions=predictions,
+        forecast=forecast,
+        model_info=f"ARIMA({ar_order}, {diff_order}, {ma_order})",
+        file_name=filename,
     )
-    lineplot.add_trace(
-        go.Scatter(
-            x=predictions.index,
-            y=predictions,
-            mode="lines",
-            name="predictions",
-        )
-    )
-    lineplot.add_trace(
-        go.Scatter(x=forecast.index, y=forecast, mode="lines", name="forecast")
-    )
-    model_info = f"ARIMA({ar_order}, {diff_order}, {ma_order})"
-    lineplot.update_layout(
-        paper_bgcolor="#eee",
-        plot_bgcolor="#eee",
-        height=350,
-        title=f"An {model_info} model fitted on {filename}",
-    )
-    lineplot.update_xaxes(fixedrange=True)
-    lineplot.update_yaxes(fixedrange=True)
 
     components = seasonal_decompose(data)
-    residuals = components.resid
-    seasonal = components.seasonal
-    trend = components.trend
-    components_subplots = make_subplots(
-        rows=3,
-        cols=1,
-        subplot_titles=("Residuals", "Seasonal", "Trend"),
-        shared_xaxes=True,
+    component_subplots = plotting.plot_ts_components(
+        trend=components.trend,
+        seasonal=components.seasonal,
+        residuals=components.resid,
+        file_name=filename,
     )
-    components_subplots.add_trace(
-        go.Scatter(x=residuals.index, y=residuals, name="residuals"),
-        row=1,
-        col=1,
-    )
-    components_subplots.add_trace(
-        go.Scatter(x=seasonal.index, y=seasonal, name="seasonal"), row=2, col=1
-    )
-    components_subplots.add_trace(
-        go.Scatter(x=trend.index, y=trend, name="trend"), row=3, col=1
-    )
-    components_subplots.update_layout(
-        height=540,
-        paper_bgcolor="#eee",
-        plot_bgcolor="#eee",
-        showlegend=False,
-        title="Seasonal Decomposition",
-    )
-    components_subplots.update_xaxes(fixedrange=True)
-    components_subplots.update_yaxes(fixedrange=True)
 
-    return lineplot, components_subplots
+    return line_plot, component_subplots
